@@ -32,11 +32,31 @@
 #include "esp_eth.h"
 #include "esp_eth_netif_glue.h"
 
+#ifdef ESP_IDF_COMP_VFS_ENABLED
 #include "esp_vfs.h"
+#include "esp_vfs_cdcacm.h"
+#include "esp_vfs_dev.h"
+#include "esp_vfs_semihost.h"
+#include "esp_vfs_usb_serial_jtag.h"
+
+#if ((ESP_IDF_VERSION_MAJOR > 4) || ((ESP_IDF_VERSION_MAJOR == 4) && (ESP_IDF_VERSION_MINOR >= 4)))
+#include "esp_vfs_console.h"
+#endif
+
 #if ((ESP_IDF_VERSION_MAJOR > 4) || ((ESP_IDF_VERSION_MAJOR == 4) && (ESP_IDF_VERSION_MINOR >= 4)))
 #include "esp_vfs_eventfd.h"
 #endif
 
+#ifdef ESP_IDF_COMP_SPIFFS_ENABLED
+#include "esp_spiffs.h"
+#endif
+
+#ifdef ESP_IDF_COMP_FATFS_ENABLED
+#include "esp_vfs_fat.h"
+#endif
+
+#endif
+
 #include "lwip/lwip_napt.h"
 #include "esp_sntp.h"
 
@@ -46,6 +66,10 @@
 #include "esp_tls.h"
 #endif
 
+#ifdef CONFIG_ESP_TLS_USING_MBEDTLS
+#include "esp_crt_bundle.h"
+#endif
+
 #ifdef ESP_IDF_COMP_APP_UPDATE_ENABLED
 #include "esp_ota_ops.h"
 #endif
